@@ -110,7 +110,7 @@ module Enumerize
 
         def matches_predicates?
           if expected_predicates.is_a?(TrueClass)
-            subject.respond_to?("#{sorted_values.first}?")
+            subject.respond_to?("#{enumerized_values.first}?")
           else
             subject.respond_to?("#{expected_attr}_#{attributes.values.first}?")
           end
@@ -121,8 +121,11 @@ module Enumerize
         end
 
         def matches_scope?
-          if expected_scope.is_a?(TrueClass)
+          case expected_scope
+          when TrueClass
             subject_class.respond_to?("with_#{expected_attr}")
+          when :shallow
+            enumerized_values.all? { |value| subject_class.respond_to?(value) }
           else
             subject_class.respond_to?(expected_scope[:scope])
           end
