@@ -1,6 +1,7 @@
 # frozen_string_literal: true
 
 require 'i18n'
+require 'active_support/inflector'
 
 module Enumerize
   class Value < String
@@ -14,15 +15,19 @@ module Enumerize
 
       super(name.to_s)
 
-      @i18n_keys = @attr.i18n_scopes.map { |s| :"#{s}.#{self}" }
+      @i18n_keys = @attr.i18n_scopes.map do |s|
+        scope = Utils.call_if_callable(s, @value)
+
+        :"#{scope}.#{self}"
+      end
       @i18n_keys << :"enumerize.defaults.#{@attr.name}.#{self}"
       @i18n_keys << :"enumerize.#{@attr.name}.#{self}"
-      @i18n_keys << self.underscore.humanize # humanize value if there are no translations
+      @i18n_keys << ActiveSupport::Inflector.humanize(ActiveSupport::Inflector.underscore(self)) # humanize value if there are no translations
       @i18n_keys
     end
 
     def text
-      I18n.t(@i18n_keys[0], :default => @i18n_keys[1..-1])
+      I18n.t(@i18n_keys[0], :default => @i18n_keys[1..-1]) if @i18n_keys
     end
 
     def ==(other)
@@ -33,6 +38,10 @@ module Enumerize
       coder.represent_object(self.class.superclass, @value)
     end
 
+    def as_json(*)
+      to_s
+    end
+
     private
 
     def predicate_call(value)
