@@ -2,7 +2,7 @@
 
 require 'test_helper'
 
-class ModuleAttributesSpec < MiniTest::Spec
+class ModuleAttributesSpec < Minitest::Spec
   it 'inherits attribute from the module' do
     mod = Module.new do
       extend Enumerize
@@ -11,9 +11,9 @@ class ModuleAttributesSpec < MiniTest::Spec
 
     klass = Class.new
     klass.send :include, mod
-    klass.enumerized_attributes[:sex].must_be_instance_of Enumerize::Attribute
-    klass.new.sex.must_equal 'male'
-    klass.sex.must_be_instance_of Enumerize::Attribute
+    expect(klass.enumerized_attributes[:sex]).must_be_instance_of Enumerize::Attribute
+    expect(klass.new.sex).must_equal 'male'
+    expect(klass.sex).must_be_instance_of Enumerize::Attribute
   end
 
   it 'uses new attributes from the module' do
@@ -24,9 +24,9 @@ class ModuleAttributesSpec < MiniTest::Spec
     klass = Class.new
     klass.send :include, mod
     mod.enumerize :sex, :in => %w[male female], :default => 'male'
-    klass.enumerized_attributes[:sex].must_be_instance_of Enumerize::Attribute
-    klass.new.sex.must_equal 'male'
-    klass.sex.must_be_instance_of Enumerize::Attribute
+    expect(klass.enumerized_attributes[:sex]).must_be_instance_of Enumerize::Attribute
+    expect(klass.new.sex).must_equal 'male'
+    expect(klass.sex).must_be_instance_of Enumerize::Attribute
   end
 
   it 'validates attributes' do
@@ -46,7 +46,7 @@ class ModuleAttributesSpec < MiniTest::Spec
 
     object = klass.new
     object.sex = 'wrong'
-    object.wont_be :valid?
-    object.errors[:sex].must_include 'is not included in the list'
+    expect(object).wont_be :valid?
+    expect(object.errors[:sex]).must_include 'is not included in the list'
   end
 end
