@@ -4,6 +4,7 @@ require 'minitest/autorun'
 require 'minitest/spec'
 require 'active_support/core_ext/kernel/reporting'
 require 'active_model'
+require 'active_job'
 require 'rails'
 begin
   require 'mongoid'
@@ -46,8 +47,16 @@ module MiscHelpers
       I18n.reload!
     end
   end
+
+  def unsafe_yaml_load(yaml)
+    if YAML.respond_to?(:unsafe_load)
+      YAML.unsafe_load(yaml)
+    else
+      YAML.load(yaml)
+    end
+  end
 end
 
-class MiniTest::Spec
+class Minitest::Spec
   include MiscHelpers
 end
